.. _context-module:

===
chi
===

The :mod:`chi` module exposes a global context object and helpers for generating
clients for interfacing with the various Chameleon services.

.. automodule:: chi
   :members:
